@@ -316,10 +316,9 @@ class DwdMosmixRequest(ScalarRequestCore):
     _resolution_type = ResolutionType.FIXED
     _resolution_base = Resolution  # use general Resolution for fixed Resolution
     _period_type = PeriodType.FIXED
-    _period_base = None
+    _period_base = Period.FUTURE
     _data_range = DataRange.FIXED
     _has_datasets = True
-    _dataset_tree = DwdMosmixParameter
     _unique_dataset = True
     _has_tidy_data = False
 
