@@ -40,6 +40,7 @@ class DwdObservationDataset(Enum):
     PRECIPITATION_MORE = "more_precip"
     WATER_EQUIVALENT = "water_equiv"
     WEATHER_PHENOMENA = "weather_phenomena"
+    WEATHER_PHENOMENA_MORE = "more_weather_phenomena"
 
 
 RESOLUTION_DATASET_MAPPING: Dict[Resolution, Dict[DwdObservationDataset, List[Period]]] = {
@@ -145,6 +146,10 @@ RESOLUTION_DATASET_MAPPING: Dict[Resolution, Dict[DwdObservationDataset, List[Pe
             Period.HISTORICAL,
             Period.RECENT,
         ],
+        DwdObservationDataset.WIND_EXTREME: [
+            Period.HISTORICAL,
+            Period.RECENT,
+        ],
         DwdObservationDataset.MOISTURE: [
             Period.HISTORICAL,
             Period.RECENT,
@@ -188,6 +193,10 @@ RESOLUTION_DATASET_MAPPING: Dict[Resolution, Dict[DwdObservationDataset, List[Pe
             Period.HISTORICAL,
             Period.RECENT,
         ],
+        DwdObservationDataset.WEATHER_PHENOMENA_MORE: [
+            Period.HISTORICAL,
+            Period.RECENT,
+        ],
     },
     Resolution.MONTHLY: {
         DwdObservationDataset.CLIMATE_SUMMARY: [
